# eric7.Plugins.VcsPlugins.vcsSubversion.SvnMergeDialog

Module implementing a dialog to enter the data for a merge operation.

### Global Attributes

None

### Classes

SvnMergeDialog | Class implementing a dialog to enter the data for a merge operation.

### Functions

None

## SvnMergeDialog

Class implementing a dialog to enter the data for a merge operation.

### Derived from

QDialog, Ui_SvnMergeDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnMergeDialog | Constructor
__enableOkButton | Private method used to enable/disable the OK-button.
getParameters | Public method to retrieve the merge data.
on_tag1Combo_editTextChanged | Private slot to handle the tag1Combo editTextChanged signal.
on_tag2Combo_editTextChanged | Private slot to handle the tag2Combo editTextChanged signal.

### Static Methods

None

#### SvnMergeDialog (Constructor)

SvnMergeDialog(mergelist1, mergelist2, targetlist, force=False, parent=None)

Constructor

mergelist1 (list of str)
  list of previously entered URLs/revisions
mergelist2 (list of str)
  list of previously entered URLs/revisions
targetlist (list of str)
  list of previously entered targets
force (bool)
  flag indicating a forced merge
parent (QWidget)
  parent widget

#### SvnMergeDialog.__enableOkButton

__enableOkButton()

Private method used to enable/disable the OK-button.

#### SvnMergeDialog.getParameters

getParameters()

Public method to retrieve the merge data.

Return:
  tuple naming two tag names or two revisions, a target and a flag indicating a forced merge

Return Type:
  tuple of (str, str, str, bool)

#### SvnMergeDialog.on_tag1Combo_editTextChanged

on_tag1Combo_editTextChanged(_text)

Private slot to handle the tag1Combo editTextChanged signal.

_text (str)
  text of the combo (unused)

#### SvnMergeDialog.on_tag2Combo_editTextChanged

on_tag2Combo_editTextChanged(_text)

Private slot to handle the tag2Combo editTextChanged signal.

_text (str)
  text of the combo (unused)

Up